@@ -1,8 +1,8 @@
 # argparse
 import argparse
 
-from je_web_runner.utils.executor.executor import execute_action
-from je_web_runner.utils.executor.executor import execute_files
+from je_web_runner.utils.executor.action_executor import execute_action
+from je_web_runner.utils.executor.action_executor import execute_files
 from je_web_runner.utils.file_process.get_dir_file_list import get_dir_files_as_list
 from je_web_runner.utils.json.json_file.json_file import read_action_json
 
